# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '10.6.beta4'
date = '2025-01-18'
banner = 'SageMath version 10.6.beta4, Release Date: 2025-01-18'
